/**
 * Copyright (c) 2006, Van
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the VAN nor the names of its contributors may be used
 * to endorse or promote products derived from this software without specific
 * prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
package van.harvest;

import com.intellij.openapi.diagnostic.Logger;
import com.intellij.openapi.options.Configurable;
import com.intellij.openapi.options.ConfigurationException;
import com.intellij.openapi.ui.Messages;
import com.intellij.ui.TableUtil;
import com.intellij.util.ui.ItemRemovable;
import com.intellij.util.ui.Table;
import com.ca.harvest.jhsdk.*;

import javax.swing.*;
import javax.swing.event.ListSelectionListener;
import javax.swing.event.ListSelectionEvent;
import javax.swing.table.AbstractTableModel;
import java.awt.event.*;
import java.awt.*;
import java.util.*;

/**
 * @author mike
 */
public class HarvestConfigurable implements Configurable {
    private static final Logger LOG = Logger.getInstance("#van.harvest.HarvestConfigurable");

    JPanel myPanel;
    private JTextField myFldBroker;
    private JTextField myFldUser;
    private JPasswordField myFldPassword;
    private ArrayList<MapItem> myList;
    private MyTableModel model;
    private JTable table1;
    private JButton btnAdd;
    private JButton btnEdit;
    private JButton btnRemove;

    private com.intellij.openapi.project.Project myProject;
    private HarvestConfiguration configuration;
    private JPanel tab;
    private JButton btnTestConnection;

    private boolean loginOK = false;

    public HarvestConfigurable(com.intellij.openapi.project.Project project) {
        myProject = project;
        myList = new ArrayList<MapItem>(0);
        model = new MyTableModel();
        configuration = myProject.getComponent(HarvestConfiguration.class);
    }

    public void disposeUIResources() {
        myPanel = null;
    }

    public JComponent createComponent() {
        table1 = new Table(model);
        table1.setSelectionMode(0);
        JScrollPane jscrollpane = new JScrollPane(table1);
        jscrollpane.setPreferredSize(new Dimension(0, table1.getRowHeight() * 11));
        tab.setLayout(new BorderLayout());
        tab.add(jscrollpane, "Center");
        table1.addMouseListener(new MouseAdapter() {
            public void mouseClicked(MouseEvent e) {
                if (e.getClickCount() == 2)
                    showEdit();
            }
        });

        table1.getSelectionModel().addListSelectionListener(new ListSelectionListener() {
            public void valueChanged(ListSelectionEvent e) {
                selectionChange();
            }
        });

        btnAdd.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                showAdd();
            }
        });

        btnEdit.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                showEdit();
            }
        });

        btnRemove.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                TableUtil.removeSelectedItems(table1);
                selectionChange();
            }
        });

        btnTestConnection.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                if (loginOK = testLogin())
                    Messages.showMessageDialog(myProject, "Login Succeed! \n\n\n\n\n", "Test Login Succeed", PluginInfo.ICON);
            }
        });
        return myPanel;
    }

    private boolean testLogin() {
        if ("".equals(myFldBroker.getText())) {
            Messages.showMessageDialog(myProject, "null Broker is not allowed!", "Test Login Fail", PluginInfo.ICON);
            return false;
        }
        JCaHarvest harvest = new JCaHarvest();
        JCaLoginExecute exec = new JCaLoginExecute();
        exec.login(harvest, myFldBroker.getText(), myFldUser.getText(), new String(myFldPassword.getPassword()));
        loginOK = exec.getResult() == 0;
        if (loginOK) harvest.logout();
        else
            Messages.showMessageDialog(myProject, harvest.getLastMessage(), "Test Login Fail", PluginInfo.ICON);
        return loginOK;
    }

    private void showAdd() {
        if (isModified()) {
            loginOK = testLogin();
            if (loginOK) {
                configuration.BROKER = myFldBroker.getText();
                configuration.USER = myFldUser.getText();
                configuration.PASSWORD = new String(myFldPassword.getPassword());
            }
        }
        if (!loginOK) loginOK = testLogin();
        if (!loginOK) return;

        MapItemDialog dialog = new MapItemDialog(myProject);
        dialog.setTitle("Add Mapping");
        dialog.show();
        if (!dialog.isOK())
            return;

        myList.add(dialog.getData());
        int i = myList.size() - 1;
        model.fireTableRowsInserted(i, i);
        table1.getSelectionModel().setSelectionInterval(i, i);
    }

    private void selectionChange() {
        ListSelectionModel listselectionmodel = table1.getSelectionModel();
        boolean flag = !listselectionmodel.isSelectionEmpty();
        btnEdit.setEnabled(flag);
        btnRemove.setEnabled(flag);
    }

    private void showEdit() {
        if (!loginOK) loginOK = testLogin();
        if (!loginOK) return;

        int i = table1.getSelectedRow();
        if (i == -1)
            return;
        MapItemDialog dialog = new MapItemDialog(myProject);
        dialog.setTitle("Edit Mapping");
        MapItem item = myList.get(i);
        dialog.setData(item);
        dialog.show();
        if (!dialog.isOK())
            return;

        myList.set(i, dialog.getData());
        model.fireTableRowsUpdated(i, i);
    }


    public String getDisplayName() {
        return null;
    }

    public String getHelpTopic() {
        return null;
    }

    public Icon getIcon() {
        return null;
    }

    public void reset() {
        HarvestConfiguration configuration = myProject.getComponent(HarvestConfiguration.class);

        myFldBroker.setText(configuration.BROKER);
        myFldUser.setText(configuration.USER);
        myFldPassword.setText(configuration.PASSWORD);
        reset(configuration.myMapItems);
    }

    private void reset(HashMap<String, MapItem> myMapItems) {
        myList = new ArrayList<MapItem>(0);
        for (Object o : myMapItems.values()) {
            myList.add((MapItem) o);
        }
    }

    public void apply() throws ConfigurationException {
        configuration.BROKER = myFldBroker.getText();
        configuration.USER = myFldUser.getText();
        configuration.PASSWORD = new String(myFldPassword.getPassword());
        for (MapItem item : myList) {
            configuration.myMapItems.put(item.CLIENT_PATH, item);
        }
    }

    public boolean isModified() {
        final boolean equals = configuration.BROKER.equals(myFldBroker.getText()) &&
                configuration.USER.equals(myFldUser.getText()) &&
                configuration.PASSWORD.equals(new String(myFldPassword.getPassword()));

        if (!equals) return true;

        if (configuration.myMapItems.size() != myList.size())
            return true;

        for (Object aMyList : myList) {
            MapItem item = (MapItem) aMyList;
            if (!item.equals(configuration.getMapItem(item.CLIENT_PATH))) {
                return true;
            }
        }
        return false;
    }

    private class MyTableModel extends AbstractTableModel
            implements ItemRemovable {

        private String columnNames[] = {
                "Client Path", "Project", "State", "Package", "View Path"
        };

        public int getColumnCount() {
            return columnNames.length;
        }

        public String getColumnName(int i) {
            return columnNames[i];
        }

        public int getRowCount() {
            return myList.size();
        }

        public Object getValueAt(int i, int j) {
            switch (j) {
                case 0: // Module name
                    return (myList.get(i)).CLIENT_PATH;
                case 1: // Project
                    return (myList.get(i)).PROJECT;
                case 2: // State
                    return (myList.get(i)).STATE;
                case 3: // Package
                    return (myList.get(i)).PACKAGE;
                case 4: // View Path
                    return (myList.get(i)).VIEW_PATH;
            }
            throw new IllegalArgumentException("Unknown column: " + j);
        }

        public void removeRow(int i) {
            myList.remove(i);
            fireTableRowsDeleted(i, i);
        }

        private MyTableModel() {
            super();
        }

    }
}
