/**
 * Copyright (c) 2006, Van
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the VAN nor the names of its contributors may be used
 * to endorse or promote products derived from this software without specific
 * prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
package van.harvest;

import com.intellij.openapi.components.ProjectComponent;
import com.intellij.openapi.util.InvalidDataException;
import com.intellij.openapi.util.WriteExternalException;
import com.intellij.openapi.util.JDOMExternalizable;
import com.intellij.openapi.util.DefaultJDOMExternalizer;
import org.jdom.Element;

import java.util.HashMap;
import java.util.Iterator;

public class HarvestConfiguration implements ProjectComponent, JDOMExternalizable {
    public String BROKER = "";
    public String USER = "";
    public String PASSWORD = "";
    public HashMap<String, MapItem> myMapItems = new HashMap<String, MapItem>();

    public void projectClosed() {
    }

    public void projectOpened() {
    }

    public void disposeComponent() {
    }

    public String getComponentName() {
        return "HarvestConfiguration";
    }

    public void initComponent() {
    }

    public MapItem getMapItem(String name) {
        return myMapItems.get(name);
    }

    public MapItem findItem(String path) {
        for (MapItem item : myMapItems.values()) {
            if (path.startsWith(item.CLIENT_PATH)) {
                return item;
            }
        }
        return null;
    }

    public void readExternal(Element element) throws InvalidDataException {
        myMapItems.clear();
        Iterator iterator = element.getChildren().iterator();
        do {
            if (!iterator.hasNext())
                break;
            Element element1 = (Element) iterator.next();
            String s = element1.getName();
            if ("MapItem".equals(s)) {
                MapItem item = new MapItem("", "", "", "", "");
                item.readExternal(element1);
                myMapItems.put(item.CLIENT_PATH, item);
            }
        } while (true);

        DefaultJDOMExternalizer.readExternal(this, element);
    }

    public void writeExternal(Element element) throws WriteExternalException {
        for (MapItem item : myMapItems.values()) {
            Element element2 = new Element("MapItem");
            element.addContent(element2);
            item.writeExternal(element2);
        }
        DefaultJDOMExternalizer.writeExternal(this, element);
    }
}
