/**
 * Copyright (c) 2006, Van
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the VAN nor the names of its contributors may be used
 * to endorse or promote products derived from this software without specific
 * prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
package van.harvest;

import com.intellij.openapi.application.PathManager;
import com.intellij.openapi.components.ProjectComponent;
import com.intellij.openapi.options.Configurable;
import com.intellij.openapi.options.ConfigurationException;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vcs.*;
import com.intellij.openapi.vcs.checkin.CheckinEnvironment;
import com.intellij.openapi.vcs.fileView.FileViewEnvironment;
import com.intellij.openapi.localVcs.LocalVcsServices;

import javax.swing.*;
import java.awt.*;
import java.io.File;
import java.util.Map;

public class HarvestVcsAdapter extends AbstractVcs implements ProjectComponent,StandardOperationsProvider {

    private HarvestVcs myHarvestVcs;

    public HarvestVcsAdapter(Project project, LocalVcsServices localVcsServices, HarvestConfiguration harvestConfiguration) {
        super(project);
        try {
            Class.forName("com.ca.harvest.jhsdk.JCaHarvest");
            myHarvestVcs = new HarvestVcs(project, localVcsServices, harvestConfiguration);
        }
        catch (Throwable e) {
        }

        if (getHarvestVcs() != null) {
            getHarvestVcs().initComponent();
        }
    }

    public HarvestVcs getHarvestVcs() {
        return myHarvestVcs;
    }

    public String getName() {
        return "Harvest";
    }

    public String getDisplayName() {
        return "Harvest";
    }

    public void projectClosed() {
        if (getHarvestVcs() != null) {
            getHarvestVcs().projectClosed();
        }
    }

    public void projectOpened() {
    }

    public void disposeComponent() {
        if (getHarvestVcs() != null) {
            getHarvestVcs().disposeComponent();
        } else {
        }
    }

    public void initComponent() {
    }

    public void start() throws VcsException {
        super.start();
        if (getHarvestVcs() != null) {
            getHarvestVcs().start();
        } else {
            throw new VcsException("Can't start Starteam plugin: harvest-sdk classes not found in IDEA classpath");
        }
    }

    public void shutdown() throws VcsException {
        if (getHarvestVcs() != null) {
            getHarvestVcs().shutdown();
        }
        super.shutdown();
    }

    public void checkinFile(String path, Object parameters) throws VcsException {
        if (getHarvestVcs() != null) {
            getHarvestVcs().checkinFile(path, parameters);
        }
    }

    public boolean checkoutFile(String path, Object parameters) throws VcsException {
        if (getHarvestVcs() != null) {
            return getHarvestVcs().checkoutFile(path, parameters);
        } else {
            return false;
        }
    }

    public byte[] getFileContent(String path, Object parameters) throws VcsException {
        if (getHarvestVcs() != null) {
            return getHarvestVcs().getFileContent(path, parameters);
        } else {
            return new byte[0];
        }
    }

    public void addFile(String folderPath, String fileName, Object parameters) throws VcsException {
        if (getHarvestVcs() != null) {
            getHarvestVcs().addFile(folderPath, fileName, parameters);
        }
    }

    public void removeFile(String path, Object parameters) throws VcsException {
        if (getHarvestVcs() != null) {
            getHarvestVcs().removeFile(path, parameters);
        }
    }

    public void removeDirectory(String path, Object parameters) throws VcsException {
        if (getHarvestVcs() != null) {
            getHarvestVcs().removeDirectory(path, parameters);
        }
    }

    public void addDirectory(String parentPath, String name, Object parameters) throws VcsException {
        if (getHarvestVcs() != null) {
            getHarvestVcs().addDirectory(parentPath, name, parameters);
        }
    }

    public FileRenameProvider getFileRenamer() {
        return getHarvestVcs() != null ? getHarvestVcs().getFileRenamer() : null;
    }

    public DirectoryRenameProvider getDirectoryRenamer() {
        return getHarvestVcs() != null ? getHarvestVcs().getDirectoryRenamer() : null;
    }

    public FileMoveProvider getFileMover() {
        return getHarvestVcs() != null ? getHarvestVcs().getFileMover() : null;
    }

    public DirectoryMoveProvider getDirectoryMover() {
        return getHarvestVcs() != null ? getHarvestVcs().getDirectoryMover() : null;
    }

    public TransactionProvider getTransactionProvider() {
        return getHarvestVcs() != null ? getHarvestVcs().getTransactionProvider() : null;
    }

    public String getComponentName() {
        return "HarvestVcsAdapter";
    }

    public Configurable getConfigurable() {
        if (getHarvestVcs() != null) {
            return getHarvestVcs().getConfigurable();
        } else {
            return new MyConfigurable();
        }
    }

    public void checkinFile(String path, Object parameters, Map userData) throws VcsException {
        getHarvestVcs().checkinFile(path,parameters,userData);
    }

    public void addFile(String folderPath, String name, Object parameters, Map userData) throws VcsException {
        getHarvestVcs().addFile(folderPath,name,parameters,userData);
    }

    public void removeFile(String path, Object parameters, Map userData) throws VcsException {
        getHarvestVcs().removeFile(path,parameters,userData);
    }

    public void addDirectory(String parentPath, String name, Object parameters, Map userData) throws VcsException {
        getHarvestVcs().addDirectory(parentPath,name,parameters,userData);
    }

    public void removeDirectory(String path, Object parameters, Map userData) throws VcsException {
        getHarvestVcs().removeDirectory(path,parameters,userData);
    }

    public static HarvestVcsAdapter getInstance(Project project) {
    return project.getComponent(HarvestVcsAdapter.class);
  }

    private static class MyConfigurable implements Configurable {

        public String getDisplayName() {
            return null;
        }

        public Icon getIcon() {
            return null;
        }

        public String getHelpTopic() {
            return null;
        }

        public JComponent createComponent() {
            final JPanel result = new JPanel(new BorderLayout());
            result.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
            result.add(new JLabel("<html>" +
                    "<font size='3'><font color='red'>" +
                    "Harvest integration requires jhsdk.jar from HSDK.</font><br>" +
                    "Please check you have CCC Harvest Client with JSDK installed properly!</html>"), BorderLayout.NORTH);
            return result;
        }

        public boolean isModified() {
            return false;
        }

        public void apply() throws ConfigurationException {
        }

        public void reset() {
        }

        public void disposeUIResources() {
        }
    }

    public FileStatusProvider getFileStatusProvider() {
        if (getHarvestVcs() != null) {
            return getHarvestVcs().getFileStatusProvider();
        } else {
            return null;
        }
    }

    public UpToDateRevisionProvider getUpToDateRevisionProvider() {
        if (getHarvestVcs() != null) {
            return getHarvestVcs().getUpToDateRevisionProvider();
        } else {
            return null;
        }
    }

    public void doActivateActions() {
        if (getHarvestVcs() != null) {
            getHarvestVcs().doActivateActions();
        }
    }

    public boolean markExternalChangesAsUpToDate() {
        return true;
    }

    public boolean supportsMarkSourcesAsCurrent() {
        return true;
    }

    public String getMenuItemText() {
        return "Harvest";
    }

    public FileViewEnvironment getFileViewEnvironment() {
    if (getHarvestVcs() != null) {
      return getHarvestVcs().getFileViewEnvironment();
    }
    else {
      return null;
    }
  }

  public CheckinEnvironment getCheckinEnvironment() {
    if (getHarvestVcs() != null) {
      return getHarvestVcs().getCheckinEnvironment();
    }
    else {
      return null;
    }
  }
}
