/**
 * Copyright (c) 2006, Van
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the VAN nor the names of its contributors may be used
 * to endorse or promote products derived from this software without specific
 * prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
package van.harvest;

import com.intellij.openapi.project.Project;
import com.intellij.openapi.ui.DialogWrapper;
import van.harvest.model.HNode;
import van.harvest.model.HWorkingViewRoot;

import javax.swing.*;
import javax.swing.event.TreeModelListener;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.TreeModel;
import javax.swing.tree.TreePath;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * Copyright (c) 2006, Van All rights reserved.
 * User: Van
 * Date: 2005-3-29 16:44:44
 */
public class HarvestViewDialog extends DialogWrapper {
    private Project myProject;
    private MapItem mapItem;
    private JPanel myPanel;
    private JTree tree1;
    private JTextField textField1;
    private JButton btnOK;
    private JButton btnCancel;

    public HarvestViewDialog(Project project, MapItem mapItem) {
        super(project, false);
        this.myProject = project;
        this.mapItem = mapItem;
        init();
    }

    public String getData() {
        return textField1.getText();
    }

    protected JComponent createCenterPanel() {
        tree1.setModel(new HTreeModel(myProject, mapItem));
        tree1.addTreeSelectionListener(new TreeSelectionListener() {
            public void valueChanged(TreeSelectionEvent e) {
                TreePath path = e.getPath();
                StringBuffer tempSpot = new StringBuffer();

                for (int counter = 0, maxCounter = path.getPathCount(); counter < maxCounter; counter++) {
                    if (counter > 0)
                        tempSpot.append("\\");
                    tempSpot.append(path.getPathComponent(counter));
                }
                tempSpot.deleteCharAt(0);
                textField1.setText(tempSpot.toString());
            }
        });

        btnOK.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                doOKAction();
            }
        });

        btnCancel.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                doCancelAction();
            }
        });

        return myPanel;
    }

    protected void init() {
        super.init();
    }

    protected Action[] createActions() {
        return new Action[0];
    }

    class HTreeModel implements TreeModel {
        private HNode root;

        public HTreeModel(Project myProject, MapItem mapItem) {
            root = new HWorkingViewRoot(myProject, mapItem);
        }

        public Object getRoot() {
            return root;
        }

        public int getChildCount(Object parent) {
            HNode node = (HNode) parent;
            return node.getChildCount();
        }

        public boolean isLeaf(Object node) {
            HNode hNode = (HNode) node;
            return hNode.isLeaf();
        }

        public void addTreeModelListener(TreeModelListener l) {

        }

        public void removeTreeModelListener(TreeModelListener l) {

        }

        public Object getChild(Object parent, int index) {
            HNode node = (HNode) parent;
            return node.getChild(index);
        }

        public int getIndexOfChild(Object parent, Object child) {
            HNode hNode = (HNode) parent;
            return hNode.getIndexOfChild((HNode) child);
        }

        public void valueForPathChanged(TreePath path, Object newValue) {
        }
    }
}
