/**
 * Copyright (c) 2006, Van
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the VAN nor the names of its contributors may be used
 * to endorse or promote products derived from this software without specific
 * prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
package van.harvest;

import com.intellij.openapi.ui.DialogWrapper;
import com.intellij.openapi.ui.TextFieldWithBrowseButton;
import com.intellij.openapi.ui.Messages;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.fileChooser.FileChooserDescriptor;
import com.intellij.openapi.fileChooser.FileChooserDescriptorFactory;
import com.intellij.openapi.fileChooser.FileChooser;
import com.intellij.openapi.vfs.VirtualFile;
import com.ca.harvest.jhsdk.JCaHarvest;
import com.ca.harvest.jhsdk.JCaContext;
import com.ca.harvest.jhsdk.JCaPackageChooser;
import com.ca.harvest.jhsdk.hutils.JCaContainer;
import com.ca.harvest.jhsdk.hutils.JCaAttrKey;

import javax.swing.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.io.File;

import van.harvest.model.HarvestManager;

/**
 * Copyright (c) 2006, Van All rights reserved.
 * User: Van
 * Date: 2005-3-24 13:08:12
 */
public class MapItemDialog extends DialogWrapper {
    private JPanel myPanel;
    private TextFieldWithBrowseButton myFldClientPath;
    private TextFieldWithBrowseButton myFldProject;
    private TextFieldWithBrowseButton myFldState;
    private TextFieldWithBrowseButton myFldPackage;
    private TextFieldWithBrowseButton myFldViewPath;
    private Project myProject;

    public MapItemDialog(Project project) {
        super(project, false);
        myProject = project;
        init();
        changeVisable();
    }

    public MapItem getData() {
        return new MapItem(myFldClientPath.getText(),
                myFldProject.getText(),
                myFldState.getText(),
                myFldPackage.getText(),
                myFldViewPath.getText());
    }

    public void setData(MapItem item) {
        myFldClientPath.setText(item.CLIENT_PATH);
        myFldProject.setText(item.PROJECT);
        myFldState.setText(item.STATE);
        myFldPackage.setText(item.PACKAGE);
        myFldViewPath.setText(item.VIEW_PATH);
        changeVisable();
    }

    protected JComponent createCenterPanel() {
        myFldClientPath.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                selectClientPath();
                changeVisable();
            }
        });

        myFldProject.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                selectProject();
                changeVisable();
            }
        });

        myFldState.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                selectState();
                changeVisable();
            }
        });

        myFldPackage.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                selectPackage();
                changeVisable();
            }
        });

        myFldViewPath.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                selectViewPath();
                changeVisable();
            }
        });

        return myPanel;
    }

    private void changeVisable() {
        if ("".equals(myFldViewPath.getText())) {
            myFldViewPath.setEditable(false);
        } else {
            myFldViewPath.setEditable(true);
        }
        if ("".equals(myFldPackage.getText())) {
            myFldViewPath.setEditable(false);
            myFldPackage.setEditable(false);
        } else {
            myFldViewPath.setEditable(true);
            myFldPackage.setEditable(true);
        }
        if ("".equals(myFldState.getText())) {
            myFldPackage.setEditable(false);
            myFldState.setEditable(false);
        } else {
            myFldPackage.setEditable(true);
            myFldState.setEditable(true);
        }
        if ("".equals(myFldProject.getText())) {
            myFldState.setEditable(false);
            myFldProject.setEditable(false);
        } else {
            myFldState.setEditable(true);
            myFldProject.setEditable(true);
        }
        if ("".equals(myFldClientPath.getText())) {
            myFldProject.setEditable(false);
        } else {
            myFldProject.setEditable(true);
        }
    }

    private void selectClientPath() {
        FileChooserDescriptor descriptor = FileChooserDescriptorFactory.createSingleFolderDescriptor();
          VirtualFile[] files = FileChooser.chooseFiles(myProject, descriptor);
          if(files.length != 0){
            myFldClientPath.setText(files[0].getPath().replace('/', File.separatorChar));
          }
    }

    private void selectProject() {
        JCaHarvest harvest = HarvestManager.getInstance().getHarvest(myProject);
        JCaContainer projects = harvest.getActiveProjectList();

        if (projects.isEmpty()) {
            Messages.showMessageDialog(myPanel, "No projects found on the server", "Error", Messages.getErrorIcon());
            return;
        }

        int projectCount = projects.getKeyElementCount(JCaAttrKey.CA_ATTRKEY_NAME);
        String[] names = new String[projectCount];
        for (int i = 0; i < projectCount; i++) {
            names[i] = projects.getString(JCaAttrKey.CA_ATTRKEY_NAME, i);
        }

        ArrayList<String> nameList = new ArrayList<String>(Arrays.asList(names));
        Collections.sort(nameList);

        String[] sortedNames = nameList.toArray(new String[nameList.size()]);

        final int i =
                Messages.showChooseDialog(myPanel,
                        "Select project",
                        "Select Project",
                        sortedNames, sortedNames[0], Messages.getQuestionIcon());

        if (i < 0) return;

        myFldProject.setText(sortedNames[i]);
    }

    private void selectState() {
        JCaContext context = HarvestManager.getInstance().getContext(myProject);
        context.setProject(myFldProject.getText());

        JCaContainer states = context.getStateList();

        if (states.isEmpty()) {
            Messages.showMessageDialog(myPanel, "No state found", "Error", Messages.getErrorIcon());
            return;
        }

        int stateCount = states.getKeyElementCount(JCaAttrKey.CA_ATTRKEY_NAME);
        String[] names = new String[stateCount];
        for (int j = 0; j < stateCount; j++) {
            names[j] = states.getString(JCaAttrKey.CA_ATTRKEY_NAME, j);
        }

        ArrayList<String> nameList = new ArrayList<String>(Arrays.asList(names));
        Collections.sort(nameList);

        String[] sortedNames = nameList.toArray(new String[nameList.size()]);

        final int i =
                Messages.showChooseDialog(myPanel,
                        "Select state",
                        "Select state",
                        sortedNames, sortedNames[0], Messages.getQuestionIcon());

        if (i < 0) return;

        myFldState.setText(sortedNames[i]);
    }

    private void selectPackage() {
        JCaContext context = HarvestManager.getInstance().getContext(myProject);
        context.setProject(myFldProject.getText());
        context.setState(myFldState.getText());

        JCaPackageChooser pkgChooser = context.getPackageChooser();
        pkgChooser.setStateObjId(context.getStateId());
        pkgChooser.execute();
        JCaContainer packages = pkgChooser.getPackageList();

        if (packages.isEmpty()) {
            Messages.showMessageDialog(myPanel, "No package found", "Error", Messages.getErrorIcon());
            return;
        }

        int pkgCount = packages.getKeyElementCount(JCaAttrKey.CA_ATTRKEY_NAME);

        String[] names = new String[pkgCount];
        for (int j = 0; j < pkgCount; j++) {
            names[j] = packages.getString(JCaAttrKey.CA_ATTRKEY_NAME, j);
        }

        ArrayList<String> nameList = new ArrayList<String>(Arrays.asList(names));
        Collections.sort(nameList);

        String[] sortedNames = nameList.toArray(new String[nameList.size()]);

        final int i =
                Messages.showChooseDialog(myPanel,
                        "Select package",
                        "Select package",
                        sortedNames, sortedNames[0], Messages.getQuestionIcon());

        if (i < 0) return;

        myFldPackage.setText(sortedNames[i]);
    }

    private void selectViewPath() {
        HarvestViewDialog dialog = new HarvestViewDialog(myProject, new MapItem(
                myFldClientPath.getText(),
                myFldProject.getText(),
                myFldState.getText(),
                myFldPackage.getText(),
                myFldViewPath.getText()
        ));
        dialog.setTitle("Select a Repository Item Path");
        dialog.show();
        if (!dialog.isOK())
            return;

        myFldViewPath.setText(dialog.getData());
    }

}
