/**
 * Copyright (c) 2006, Van
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the VAN nor the names of its contributors may be used
 * to endorse or promote products derived from this software without specific
 * prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
package van.harvest.actions;

import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vcs.*;
import com.intellij.openapi.vcs.ui.CheckinFileDialog;
import com.intellij.openapi.vfs.VirtualFile;
import van.harvest.HarvestVcs;

/**
 * @author mike
 */
public class CheckinAction extends BasicAction {
    protected boolean isEnabled(Project project, AbstractVcs vcs, VirtualFile file) {
        return FileStatusManager.getInstance(project).getStatus(file) == FileStatus.MODIFIED;
    }

    protected String getActionName(AbstractVcs vcs) {
        return "Checking in files to " + vcs.getDisplayName();
    }

    protected void perform(Project project, HarvestVcs activeVcs, VirtualFile file, DataContext context)
            throws VcsException {
        // todo decide if check-in comments are actually required
        //String checkinMessage = getCheckinMesssage(project, activeVcs);
        //if (checkinMessage == null) return;
        //AbstractVcsHelper.getInstance(project).doCheckinFiles(new VirtualFile[]{file}, checkinMessage);
        activeVcs.checkinFile(file.getPresentableUrl(),null);

        AbstractVcsHelper.getInstance(project).markFileAsUpToDate(file);

    }

    private String getCheckinMesssage(Project project, HarvestVcs activeVcs) {

        if (activeVcs.getCheckinOptions().getValue()) {
            CheckinFileDialog d = new CheckinFileDialog(project, activeVcs.getCheckinEnvironment());
            d.show();
            if (!d.isOK()) {
                return null;
            } else {
                return d.getPreparedComment(HarvestVcs.getInstance(project).getCheckinEnvironment());
            }
        } else {
            return CheckinFileDialog.getInitialMessage(project);
        }

    }

}
