/**
 * Copyright (c) 2006, Van
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the VAN nor the names of its contributors may be used
 * to endorse or promote products derived from this software without specific
 * prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
package van.harvest.model;

import van.harvest.MapItem;
import com.intellij.openapi.project.Project;

/**
 */
public class HItem extends HNode {
    protected Project project;
    protected MapItem mapItem;
    protected HNode[] cachedChildren;

    private String name;
    private String viewPath;

    public HItem(Project project, MapItem mapItem, String viewPath) {
        this.project = project;
        this.mapItem = mapItem;
        this.viewPath = viewPath;
        name = viewPath.substring(viewPath.lastIndexOf('\\') + 1);
    }

    public int getChildCount() {
        return getChildren().length;
    }

    public boolean isLeaf() {
        return true;
    }

    public HNode getChild(int index) {
        return getChildren()[index];
    }

    public HNode[] getChildren() {
        return new HNode[0];
    }

    public int getIndexOfChild(HNode child) {
        HNode[] children = getChildren();
        for (int i = 0; i < children.length; i++) {
            HItem hNode = (HItem) children[i];
            if (hNode.equals(child))
                return i;
        }
        return -1;
    }

    public String getLabel() {
        return name;
    }

    public boolean equals(Object obj) {
        if (obj == null) return false;
        if (obj instanceof HItem) {
            HItem hItem = (HItem) obj;
            return (name.equals(hItem.getLabel()) && viewPath.equals(hItem.getViewPath()));
        }
        return false;
    }

    public int hashCode() {
        return name.hashCode() + viewPath.hashCode();
    }

    public String getViewPath() {
        return viewPath;
    }

}
