/**
 * Copyright (c) 2006, Van
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the VAN nor the names of its contributors may be used
 * to endorse or promote products derived from this software without specific
 * prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
package van.harvest.model;

import van.harvest.MapItem;
import com.ca.harvest.jhsdk.JCaContext;
import com.ca.harvest.jhsdk.JCaItem;
import com.ca.harvest.jhsdk.hutils.JCaHarvestException;
import com.intellij.openapi.project.Project;

/**
 */
public class HItemPath extends HItem {
    public HItemPath(Project project, MapItem mapItem, String viewPath) {
        super(project, mapItem, viewPath);
    }

    public boolean isLeaf() {
        return false;
    }

    public HNode[] getChildren() {
        if (cachedChildren == null) {
            try {
                JCaContext context = HarvestManager.getInstance().getContext(project);
                context.setProject(mapItem.PROJECT);
                context.setState(mapItem.STATE);
                context.setPackage(mapItem.PACKAGE);
                context.setViewPath(getViewPath());
                JCaItem parentItem = context.getViewPathItem();
                JCaItem items[] = parentItem.getItemPathList(true);
                cachedChildren = new HNode[items.length];
                for (int i = 0; i < items.length; i++) {
                    JCaItem item = items[i];
                    cachedChildren[i] = new HItemPath(project, mapItem, getViewPath() + "\\" + item.getName());
                }
            } catch (JCaHarvestException e) {
                cachedChildren = new HNode[0];
            }
        }
        return cachedChildren;
    }
}
