/**
 * Copyright (c) 2006, Van
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the VAN nor the names of its contributors may be used
 * to endorse or promote products derived from this software without specific
 * prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
package van.harvest.model;

import com.ca.harvest.jhsdk.JCaHarvest;
import com.ca.harvest.jhsdk.JCaContext;
import com.ca.harvest.jhsdk.JCaLoginExecute;
import com.intellij.openapi.project.Project;

import van.harvest.HarvestConfiguration;

/**
 */
public class HarvestManager {
    private static HarvestManager myInstance;

    private JCaHarvest harvest;
    private JCaContext context;
    private boolean login = false;

    private HarvestManager() {
    }

    public static HarvestManager getInstance() {
        if (myInstance == null) {
            myInstance = new HarvestManager();
        }
        return myInstance;
    }

    public JCaHarvest getHarvest(Project project) {
        HarvestConfiguration configuration = project.getComponent(HarvestConfiguration.class);
        if (harvest == null && !"".equals(configuration.BROKER)) {
            harvest = new JCaHarvest(configuration.BROKER);
            JCaLoginExecute exec = new JCaLoginExecute();
            exec.login(harvest, configuration.BROKER, configuration.USER, configuration.PASSWORD);
            login = exec.getResult() == 0;
        }
        return harvest;
    }

    public JCaContext getContext(Project project) {
        if (context == null) {
            context = getHarvest(project).getContext();
        }
        return context;
    }

    public void logout(Project project) {
        if (harvest !=null) harvest.logout();
        context = null;
        harvest = null;
    }

    public boolean isLogin() {
        return login;
    }

}
